@@ -61,19 +61,31 @@ class Node(metaclass=abc.ABCMeta):
 
         if self.conf.nats.sub_conf and self.conf.nats.sub_conf.subject:
             logger.debug("sub>>>")
-            osub = await self.js.subscribe(
-                self.conf.nats.sub_conf.subject,
-                queue=self.conf.nats.sub_conf.queue,
-                durable=self.conf.nats.sub_conf.durable,
-                stream=self.conf.nats.sub_conf.stream,
-                config=self.conf.nats.sub_conf.config,
-                manual_ack=self.conf.nats.sub_conf.manual_ack,
-                ordered_consumer=self.conf.nats.sub_conf.ordered_consumer,
-                idle_heartbeat=self.conf.nats.sub_conf.idle_heartbeat,
-                flow_control=self.conf.nats.sub_conf.flow_control,
-                pending_msgs_limit=self.conf.nats.sub_conf.pending_msgs_limit,
-                pending_bytes_limit=self.conf.nats.sub_conf.pending_bytes_limit
-            )
+            # 拉取模式
+            if self.conf.nats.sub_conf.mode == "pull":
+                osub = self.js.pull_subscribe(
+                    self.conf.nats.sub_conf.subject,
+                    durable=self.conf.nats.sub_conf.durable,
+                    stream=self.conf.nats.sub_conf.stream,
+                    config=self.conf.nats.sub_conf.config,
+                    pending_msgs_limit=self.conf.nats.sub_conf.pending_msgs_limit,
+                    pending_bytes_limit=self.conf.nats.sub_conf.pending_bytes_limit
+                )
+            else:
+                # 推送模式
+                osub = await self.js.subscribe(
+                    self.conf.nats.sub_conf.subject,
+                    queue=self.conf.nats.sub_conf.queue,
+                    durable=self.conf.nats.sub_conf.durable,
+                    stream=self.conf.nats.sub_conf.stream,
+                    config=self.conf.nats.sub_conf.config,
+                    manual_ack=self.conf.nats.sub_conf.manual_ack,
+                    ordered_consumer=self.conf.nats.sub_conf.ordered_consumer,
+                    idle_heartbeat=self.conf.nats.sub_conf.idle_heartbeat,
+                    flow_control=self.conf.nats.sub_conf.flow_control,
+                    pending_msgs_limit=self.conf.nats.sub_conf.pending_msgs_limit,
+                    pending_bytes_limit=self.conf.nats.sub_conf.pending_bytes_limit
+                )
 
             while True:
                 try:
